==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeComment.h <==
// class gnu.xml.libxmlj.dom.GnomeComment

// class file dependencies
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class ff4468794e869bd0 gnu_xml_libxmlj_dom_GnomeComment
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeCharacterData

#include "gnu/xml/libxmlj/dom/GnomeCharacterData.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeComment_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeComment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$refs	_jc_gnu_xml_libxmlj_dom_GnomeComment$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object	_jc_gnu_xml_libxmlj_dom_GnomeComment$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtable	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeComment$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods	gnu_xml_libxmlj_dom_GnomeComment;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs	gnu_xml_libxmlj_dom_GnomeComment;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeComment;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object {
	_jc_gnu_xml_libxmlj_dom_GnomeComment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype _jc_gnu_xml_libxmlj_dom_GnomeComment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeComment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeComment$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeComment_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeComment.h <==
// class gnu.xml.libxmlj.dom.GnomeComment

// class file dependencies
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class ff4468794e869bd0 gnu_xml_libxmlj_dom_GnomeComment
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeCharacterData

#include "gnu/xml/libxmlj/dom/GnomeCharacterData.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeComment_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeComment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$refs	_jc_gnu_xml_libxmlj_dom_GnomeComment$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object	_jc_gnu_xml_libxmlj_dom_GnomeComment$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtable	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeComment$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vmethods	gnu_xml_libxmlj_dom_GnomeComment;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_refs	gnu_xml_libxmlj_dom_GnomeComment;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeComment$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeComment;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeComment$object {
	_jc_gnu_xml_libxmlj_dom_GnomeComment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeComment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeComment$vtype _jc_gnu_xml_libxmlj_dom_GnomeComment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeComment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeComment$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeComment_H_ */
